/**
  ******************************************************************************
  * @file     ADC_CFG.c
  * @author   SINOMCU-AE
  * @brief    ADC config
  *    
  *          This file provides functions to ADC config:
  *              ADC IN1(PA1) IN2(PA2) IN3(PA3) IN4(PA4),DMA Transfer,Timer Trig
  *         
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * The present firmware which is for guidance only aims at providing customers
  * with coding information regarding their products in order for them to save
  * time. As a result, SinoMCU shall not be held liable for any direct,indirect
  * or consequential damages with respect to any claims arising from the content 
  * of such firmware and/or the use made by customers of the coding information 
  * contained herein in connection with their products.
  *
  * <h2><center>&copy; Copyright (c) 2021 sinomcu All rights reserved.</center></h2>
  *
  ******************************************************************************
  */
#include "user_config.h"   
#include "ADC_CFG.h"

/**
  * @brief  ADC Pin Initialization
  *  PA1   --> ADC_IN1
  *  PA2   --> ADC_IN2
  *  PA3   --> ADC_IN3
  *  PA4   --> ADC_IN4
  * @param  None
  * @retval None
  */
void adc_pin_init(void) {
  MS32_GPIO_InitTypeDef GpioInitStruct = {0};

  MS32_GPIO_StructInit(&GpioInitStruct);  
  GpioInitStruct.Pin  = MS32_GPIO_PIN_1 | MS32_GPIO_PIN_2 |MS32_GPIO_PIN_3 |MS32_GPIO_PIN_4;
  GpioInitStruct.Mode = MS32_GPIO_MODE_ANALOG;
  GpioInitStruct.Pull = MS32_GPIO_PULL_NO;
  MS32_GPIO_Init(GPIOA, &GpioInitStruct);             // init function had enable clock
}

/**
  * @brief  ADC Initialization Function
  * @param  None
  * @retval None
  */
void adc_init(void)
{
  MS32_ADC_InitTypeDef AdcInitStruct = {0};
  MS32_ADC_REG_InitTypeDef AdcRegInitStruct = {0};

  adc_pin_init();

  //if (MS32_ADC_IsEnabled(ADC1) == 0)                     // ADC must be disabled. 
  MS32_ADC_StructInit(&AdcInitStruct); 
  AdcInitStruct.Clock = MS32_ADC_CLOCK_ASYNC;              // need ADC close
  AdcInitStruct.Resolution = MS32_ADC_RESOLUTION_12B;
  AdcInitStruct.DataAlignment = MS32_ADC_DATA_ALIGN_RIGHT;
  AdcInitStruct.LowPowerMode = MS32_ADC_LP_MODE_NONE;
  MS32_ADC_Init(ADC1, &AdcInitStruct);                     // init function had enable clock
  
  MS32_ADC_REG_StructInit(&AdcRegInitStruct);
  //user_config.h, 0:ADC TRIG TIM1 TRGO UIF,1:ADC TRIG TIM1 TRGO OC3REF,2:ADC TRIG TIM1 TRGO OC4REF 
#if(( ADC_HW_TRIG == 0) ||( ADC_HW_TRIG == 1) ||( ADC_HW_TRIG == 2) ) 
  AdcRegInitStruct.TriggerSource = MS32_ADC_REG_TRIG_EXT_TIM1_TRGO;
#elif( ADC_HW_TRIG == 3)     // user_config.h, 3:ADC TRIG TIM1 CH4
  AdcRegInitStruct.TriggerSource = MS32_ADC_REG_TRIG_EXT_TIM1_CH4;
#elif( ADC_HW_TRIG == 4)     // user_config.h, 4:ADC TRIG TIM2 TRGO
  AdcRegInitStruct.TriggerSource = MS32_ADC_REG_TRIG_EXT_TIM2_TRGO;
#else
#error user_config.h,ADC Hardware Tigger select Error!!!
#endif  
  AdcRegInitStruct.SequencerDiscont = MS32_ADC_REG_SEQ_DISCONT_DISABLE;
  AdcRegInitStruct.ContinuousMode = MS32_ADC_REG_CONV_SINGLE;
  AdcRegInitStruct.DMATransfer = MS32_ADC_REG_DMA_TRANSFER_UNLIMITED;
  AdcRegInitStruct.Overrun = MS32_ADC_REG_OVR_DATA_PRESERVED;
  MS32_ADC_REG_Init(ADC1, &AdcRegInitStruct);
  
  MS32_ADC_REG_SetSequencerScanDirection(ADC1, MS32_ADC_REG_SEQ_SCAN_DIR_FORWARD);       // CH1 -> CH4
  MS32_ADC_SetSamplingTimeCommonChannels(ADC1, MS32_ADC_SAMPLINGTIME_1CYCLE_5);          // user adjust this parameter for application
  // need ADSTART=0   
  MS32_ADC_REG_SetSequencerChAdd(ADC1, MS32_ADC_CHANNEL_1 | MS32_ADC_CHANNEL_2 |MS32_ADC_CHANNEL_3 |MS32_ADC_CHANNEL_4);  
}

/******************************** END OF FILE *********************************/
